@@ -24,7 +24,6 @@
 
 #include "navigator.h"
 #include "picture_viewer.h"
-#include "thumbnail_viewer.h"
 #include "main_window.h"
 
 static ThunarVfsMimeDatabase *mime_dbase = NULL;
@@ -236,7 +235,7 @@ int main(int argc, char **argv)
     gint window_width = xfce_rc_read_int_entry(xfce_rc, "LastWindowWidth", 400);
     gint window_height = xfce_rc_read_int_entry(xfce_rc, "LastWindowHeight", 300);
     gint slideshow_timeout = xfce_rc_read_int_entry(xfce_rc, "SlideShowTimeout", 5000);
-    gint max_cache = xfce_rc_read_int_entry(xfce_rc, "MaxImagesCacheSize", 1);
+    gint max_cache = xfce_rc_read_int_entry(xfce_rc, "MaxImagesCacheSize", 64);
     gboolean preload_during_slideshow = xfce_rc_read_bool_entry (xfce_rc, "PreloadDuringSlideShow", FALSE);
     gboolean override_bg_color = xfce_rc_read_bool_entry (xfce_rc, "OverrideBgColor", FALSE);
 
@@ -295,13 +294,15 @@ int main(int argc, char **argv)
                         if(!strcmp(file_media, "image"))
                         {
                             RsttoNavigatorEntry *entry = rstto_navigator_entry_new(navigator, info);
-                            gint i = rstto_navigator_add (navigator, entry);
+                            rstto_navigator_add (navigator, entry, TRUE);
                         }
                     }
                     else
                     {
                         GDir *dir = g_dir_open(argv[n], 0, NULL);
                         const gchar *filename = g_dir_read_name(dir);
+                        rstto_navigator_set_monitor_handle_for_dir(navigator, info->path);
+
                         while (filename)
                         {
                             gchar *path_name = g_strconcat(argv[n],  "/", filename, NULL);
@@ -313,7 +314,7 @@ int main(int argc, char **argv)
                                 if(!strcmp(file_media, "image"))
                                 {
                                     RsttoNavigatorEntry *entry = rstto_navigator_entry_new(navigator, file_info);
-                                    rstto_navigator_add (navigator, entry);
+                                    rstto_navigator_add (navigator, entry, FALSE);
                                 }
                                 g_free(file_media);
                                 thunar_vfs_path_unref(file_path);
@@ -382,19 +383,19 @@ int main(int argc, char **argv)
                                     if(!strcmp(file_media, "image"))
                                     {
                                         RsttoNavigatorEntry *entry = rstto_navigator_entry_new(navigator, file_info);
-                                        gint i = rstto_navigator_add (navigator, entry);
+                                        gint i = rstto_navigator_add (navigator, entry, FALSE);
                                         if (path_dir == NULL)
                                         {
                                             if (!strcmp(path_name, argv[1]))
                                             {
-                                                rstto_navigator_set_file(navigator, i);
+                                                rstto_navigator_set_file_nr(navigator, i);
                                             }
                                         }
                                         else
                                         {
                                             if (!strcmp(path_name, path_dir))
                                             {
-                                                rstto_navigator_set_file(navigator, i);
+                                                rstto_navigator_set_file_nr(navigator, i);
                                             }
 
                                         }
@@ -414,6 +415,8 @@ int main(int argc, char **argv)
                     {
                         GDir *dir = g_dir_open(argv[1], 0, NULL);
                         const gchar *filename = g_dir_read_name(dir);
+
+                        rstto_navigator_set_monitor_handle_for_dir(navigator, info->path);
                         while (filename)
                         {
                             gchar *path_name = g_strconcat(path_dir,  "/", filename, NULL);
@@ -425,7 +428,7 @@ int main(int argc, char **argv)
                                 if(!strcmp(file_media, "image"))
                                 {
                                     RsttoNavigatorEntry *entry = rstto_navigator_entry_new(navigator, file_info);
-                                    rstto_navigator_add (navigator, entry);
+                                    rstto_navigator_add (navigator, entry, FALSE);
                                 }
                                 g_free(file_media);
                                 thunar_vfs_path_unref(file_path);
