@@ -56,6 +56,10 @@ static void
 rstto_thumbnail_bar_size_allocate(GtkWidget *, GtkAllocation *);
 static gboolean 
 rstto_thumbnail_bar_expose(GtkWidget *, GdkEventExpose *);
+static void
+rstto_thumbnail_bar_realize(GtkWidget *widget);
+static void
+rstto_thumbnail_bar_unrealize(GtkWidget *widget);
 
 static gboolean
 cb_rstto_thumbnail_bar_thumbnail_button_press_event (RsttoThumbnail *thumb, GdkEventButton *event);
@@ -65,10 +69,11 @@ static gboolean
 cb_rstto_thumbnail_bar_thumbnail_motion_notify_event (RsttoThumbnail *thumb,
                                              GdkEventMotion *event,
                                              gpointer user_data);
+
 static gboolean
-cb_rstto_thumbnail_bar_thumbnail_scroll_event (RsttoThumbnail *thumb,
-                                               GdkEventScroll *event,
-                                               gpointer *user_data);
+cb_rstto_thumbnail_bar_scroll_event (RsttoThumbnailBar *bar,
+                                     GdkEventScroll *event,
+                                     gpointer *user_data);
 
 static void
 rstto_thumbnail_bar_add(GtkContainer *container, GtkWidget *child);
@@ -100,7 +105,7 @@ cb_rstto_thumbnail_bar_nav_entry_removed(RsttoNavigator *nav,
                                     RsttoThumbnailBar *bar);
 
 static void
-cb_rstto_thumbnail_bar_thumbnail_toggled (RsttoThumbnail *thumb, RsttoThumbnailBar *bar);
+cb_rstto_thumbnail_bar_thumbnail_clicked (RsttoThumbnail *thumb, RsttoThumbnailBar *bar);
 
 static gint
 cb_rstto_thumbnail_bar_compare (RsttoThumbnail *a, RsttoThumbnail *b);
@@ -139,12 +144,16 @@ rstto_thumbnail_bar_init(RsttoThumbnailBar *bar)
 
     bar->priv->auto_center = TRUE;
 
-	GTK_WIDGET_SET_FLAGS(bar, GTK_NO_WINDOW);
-	gtk_widget_set_redraw_on_allocate(GTK_WIDGET(bar), FALSE);
+	GTK_WIDGET_UNSET_FLAGS(bar, GTK_NO_WINDOW);
+	gtk_widget_set_redraw_on_allocate(GTK_WIDGET(bar), TRUE);
+    gtk_widget_set_events (GTK_WIDGET(bar),
+                           GDK_SCROLL_MASK);
 
     bar->priv->orientation = GTK_ORIENTATION_HORIZONTAL;
     bar->priv->offset = 0;
 
+    g_signal_connect(G_OBJECT(bar), "scroll_event", G_CALLBACK(cb_rstto_thumbnail_bar_scroll_event), NULL);
+
 }
 
 static void
@@ -161,6 +170,8 @@ rstto_thumbnail_bar_class_init(RsttoThumbnailBarClass *bar_class)
     widget_class->size_request = rstto_thumbnail_bar_size_request;
     widget_class->size_allocate = rstto_thumbnail_bar_size_allocate;
     widget_class->expose_event = rstto_thumbnail_bar_expose;
+    widget_class->realize = rstto_thumbnail_bar_realize;
+    widget_class->unrealize = rstto_thumbnail_bar_unrealize;
 
 	container_class->add = rstto_thumbnail_bar_add;
 	container_class->remove = rstto_thumbnail_bar_remove;
@@ -173,6 +184,13 @@ rstto_thumbnail_bar_class_init(RsttoThumbnailBarClass *bar_class)
 		_("The amount of space between the thumbnails"),
 		0, G_MAXINT, 3,
 		G_PARAM_READABLE));
+
+	gtk_widget_class_install_style_property (widget_class,
+		g_param_spec_int ("border_width",
+		_("Border Width"),
+		_("The border width of the thumbnail-bar"),
+		0, G_MAXINT, 3,
+		G_PARAM_READABLE));
 }
 
 static void
@@ -180,6 +198,9 @@ rstto_thumbnail_bar_size_request(GtkWidget *widget, GtkRequisition *requisition)
 {
     RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR(widget);
     gint border_width = GTK_CONTAINER(bar)->border_width;
+
+    gtk_widget_style_get(widget, "border-width", &border_width, NULL);
+
     GSList *iter;
 
 	GtkRequisition child_requisition;
@@ -198,6 +219,7 @@ rstto_thumbnail_bar_size_request(GtkWidget *widget, GtkRequisition *requisition)
     requisition->width += (border_width * 2);
 
 	widget->requisition = *requisition;
+    GTK_CONTAINER(bar)->border_width = border_width;
 }
 
 static void
@@ -211,13 +233,23 @@ rstto_thumbnail_bar_size_allocate(GtkWidget *widget, GtkAllocation *allocation)
     GtkAllocation child_allocation;
     GtkRequisition child_requisition;
 
-    child_allocation.x = allocation->x + border_width;
-    child_allocation.y = allocation->y + border_width;
-    child_allocation.height = 0;
-    child_allocation.width = 0;
+    child_allocation.x = border_width;
+    child_allocation.y = border_width;
+    child_allocation.height = border_width * 2;
+    child_allocation.width = border_width * 2;
 
     GSList *iter = bar->priv->thumbs;
 
+    if (GTK_WIDGET_REALIZED(widget))
+    {
+        gdk_window_move_resize (widget->window,
+                                allocation->x,
+                                allocation->y,
+                                allocation->width,
+                                allocation->height);
+    }
+
+
     switch(bar->priv->orientation)
     {
         case GTK_ORIENTATION_HORIZONTAL:
@@ -326,33 +358,36 @@ rstto_thumbnail_bar_expose(GtkWidget *widget, GdkEventExpose *ex)
 
     GdkEventExpose *n_ex = g_new0(GdkEventExpose, 1);
 
+    gint border_width = GTK_CONTAINER(bar)->border_width;
+
     n_ex->type = ex->type;
     n_ex->window = ex->window;
     n_ex->send_event = ex->send_event;
-    n_ex->area.x = ex->area.x;
-    n_ex->area.y = ex->area.y;
+    n_ex->area.x = border_width;
+    n_ex->area.y = border_width;
     n_ex->area.width = ex->area.width;
     n_ex->area.height = ex->area.height;
     n_ex->count = ex->count;
 
     while(iter)
     {
+
         if (GTK_WIDGET_VISIBLE(iter->data) == TRUE)
         {
             switch (bar->priv->orientation)
             {
                 case GTK_ORIENTATION_HORIZONTAL:
                     /* why are these widgets not filtered out with the GTK_WIDGET_VISIBLE macro?*/
-                    if (GTK_WIDGET(iter->data)->allocation.x > (GTK_WIDGET(bar)->allocation.x + GTK_WIDGET(bar)->allocation.width))
+                    if (GTK_WIDGET(iter->data)->allocation.x > GTK_WIDGET(bar)->allocation.width)
                         break;
-                    if ((GTK_WIDGET(iter->data)->allocation.x + GTK_WIDGET(iter->data)->allocation.width) <= (GTK_WIDGET(bar)->allocation.x))
+                    if ((GTK_WIDGET(iter->data)->allocation.x + GTK_WIDGET(iter->data)->allocation.width) < 0)
                         break;
 
                     /* first (partially) visible thumbnail */
-                    if (( GTK_WIDGET(iter->data)->allocation.x - GTK_WIDGET(bar)->allocation.x) < 0)
+                    if (GTK_WIDGET(iter->data)->allocation.x < 0)
                     {
-                        n_ex->area.x = GTK_WIDGET(bar)->allocation.x;
-                        n_ex->area.width = GTK_WIDGET(iter->data)->allocation.width - (GTK_WIDGET(bar)->allocation.x - GTK_WIDGET(bar)->allocation.x);
+                        n_ex->area.x = 0;
+                        n_ex->area.width = GTK_WIDGET(iter->data)->allocation.width;
                     }
                     else
                     {
@@ -367,7 +402,7 @@ rstto_thumbnail_bar_expose(GtkWidget *widget, GdkEventExpose *ex)
                         {
                             /* everything in between */
                             n_ex->area.x = GTK_WIDGET(iter->data)->allocation.x;
-                            n_ex->area.width = GTK_WIDGET(iter->data)->allocation.width;
+                            n_ex->area.width = GTK_WIDGET(bar)->allocation.width - n_ex->area.x;
                         }
 
                     }
@@ -378,16 +413,16 @@ rstto_thumbnail_bar_expose(GtkWidget *widget, GdkEventExpose *ex)
                     break;
                 case GTK_ORIENTATION_VERTICAL:
                     /* why are these widgets not filtered out with the GTK_WIDGET_VISIBLE macro?*/
-                    if (GTK_WIDGET(iter->data)->allocation.y > (GTK_WIDGET(bar)->allocation.y + GTK_WIDGET(bar)->allocation.height))
+                    if (GTK_WIDGET(iter->data)->allocation.y > GTK_WIDGET(bar)->allocation.height)
                         break;
-                    if ((GTK_WIDGET(iter->data)->allocation.y + GTK_WIDGET(iter->data)->allocation.height) <= (GTK_WIDGET(bar)->allocation.y))
+                    if ((GTK_WIDGET(iter->data)->allocation.y + GTK_WIDGET(iter->data)->allocation.height) < 0 )
                         break;
 
                     /* first (partially) visible thumbnail */
-                    if (( GTK_WIDGET(iter->data)->allocation.y - GTK_WIDGET(bar)->allocation.y) < 0)
+                    if (GTK_WIDGET(iter->data)->allocation.y < 0)
                     {
-                        n_ex->area.y = GTK_WIDGET(bar)->allocation.y;
-                        n_ex->area.height = GTK_WIDGET(iter->data)->allocation.height - (GTK_WIDGET(bar)->allocation.y - GTK_WIDGET(bar)->allocation.y);
+                        n_ex->area.y = 0;
+                        n_ex->area.height = GTK_WIDGET(iter->data)->allocation.height;
                     }
                     else
                     {
@@ -402,7 +437,7 @@ rstto_thumbnail_bar_expose(GtkWidget *widget, GdkEventExpose *ex)
                         {
                             /* everything in between */
                             n_ex->area.y = GTK_WIDGET(iter->data)->allocation.y;
-                            n_ex->area.height = GTK_WIDGET(iter->data)->allocation.height;
+                            n_ex->area.height = GTK_WIDGET(bar)->allocation.height - n_ex->area.y;
                         }
 
                     }
@@ -419,6 +454,52 @@ rstto_thumbnail_bar_expose(GtkWidget *widget, GdkEventExpose *ex)
     return FALSE;
 }
 
+static void
+rstto_thumbnail_bar_realize(GtkWidget *widget)
+{
+    RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR(widget);
+
+    GtkAllocation view_allocation;
+    GdkWindowAttr attributes;
+    gint attributes_mask;
+    gint event_mask;
+    gint border_width = 0;
+
+    GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
+
+    attributes.x = widget->allocation.x + border_width;
+    attributes.y = widget->allocation.y + border_width;
+    attributes.width = widget->allocation.width - border_width * 2;
+    attributes.height = widget->allocation.height - border_width * 2;
+    attributes.window_type = GDK_WINDOW_CHILD;
+    attributes.wclass = GDK_INPUT_OUTPUT;
+    attributes.visual = gtk_widget_get_visual (widget);
+    attributes.colormap = gtk_widget_get_colormap (widget);
+    attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK;
+
+    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
+
+    widget->window = gdk_window_new (gtk_widget_get_parent_window (widget),
+                   &attributes, attributes_mask);
+    gdk_window_set_user_data (widget->window, bar);
+
+    attributes.x = 0;
+    attributes.y = 0;
+    widget->style = gtk_style_attach (widget->style, widget->window);
+    gtk_style_set_background (widget->style, widget->window, GTK_STATE_NORMAL);
+
+}
+
+static void
+rstto_thumbnail_bar_unrealize(GtkWidget *widget)
+{
+    RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR(widget);
+
+    if (GTK_WIDGET_CLASS (parent_class)->unrealize)
+        (* GTK_WIDGET_CLASS (parent_class)->unrealize) (widget);
+
+}
+
 GtkWidget *
 rstto_thumbnail_bar_new(RsttoNavigator *navigator)
 {
@@ -531,11 +612,10 @@ cb_rstto_thumbnail_bar_nav_new_entry(RsttoNavigator *nav, gint nr, RsttoNavigato
     {
         thumb = rstto_thumbnail_new(entry, NULL);
     }
-    g_signal_connect(G_OBJECT(thumb), "toggled", G_CALLBACK(cb_rstto_thumbnail_bar_thumbnail_toggled), bar);
+    g_signal_connect(G_OBJECT(thumb), "clicked", G_CALLBACK(cb_rstto_thumbnail_bar_thumbnail_clicked), bar);
     g_signal_connect(G_OBJECT(thumb), "button_press_event", G_CALLBACK(cb_rstto_thumbnail_bar_thumbnail_button_press_event), NULL);
     g_signal_connect(G_OBJECT(thumb), "button_release_event", G_CALLBACK(cb_rstto_thumbnail_bar_thumbnail_button_release_event), NULL);
     g_signal_connect(G_OBJECT(thumb), "motion_notify_event", G_CALLBACK(cb_rstto_thumbnail_bar_thumbnail_motion_notify_event), NULL);
-    g_signal_connect(G_OBJECT(thumb), "scroll_event", G_CALLBACK(cb_rstto_thumbnail_bar_thumbnail_scroll_event), NULL);
     gtk_container_add(GTK_CONTAINER(bar), thumb);
     gtk_widget_show(thumb);
 }
@@ -563,17 +643,15 @@ cb_rstto_thumbnail_bar_nav_iter_changed(RsttoNavigator *nav, gint nr, RsttoNavig
 
     while (iter != NULL)
     {
-        if (entry != rstto_thumbnail_get_entry(RSTTO_THUMBNAIL(iter->data)))
+        if (entry == rstto_thumbnail_get_entry(RSTTO_THUMBNAIL(iter->data)))
         {
-            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(iter->data), FALSE);
-        }
-        else
-        {
-            gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(iter->data), TRUE);
+            //gtk_button_clicked(GTK_BUTTON(iter->data));
+            break;
         }
         i++;
         iter = g_slist_next(iter);
     }
+
     /* If the children should be autocentered... resize */
     if (bar->priv->auto_center == TRUE)
         gtk_widget_queue_resize(GTK_WIDGET(bar));
@@ -592,9 +670,9 @@ cb_rstto_thumbnail_bar_nav_reordered (RsttoNavigator *nav, RsttoThumbnailBar *ba
 }
 
 static void
-cb_rstto_thumbnail_bar_thumbnail_toggled (RsttoThumbnail *thumb, RsttoThumbnailBar *bar)
+cb_rstto_thumbnail_bar_thumbnail_clicked (RsttoThumbnail *thumb, RsttoThumbnailBar *bar)
 {
-    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(thumb)) == TRUE)
+    if (thumb->selected == TRUE)
     {
         bar->priv->auto_center = TRUE;
         rstto_navigator_entry_select (rstto_thumbnail_get_entry(thumb));
@@ -689,11 +767,10 @@ cb_rstto_thumbnail_bar_thumbnail_motion_notify_event (RsttoThumbnail *thumb,
 }
 
 static gboolean
-cb_rstto_thumbnail_bar_thumbnail_scroll_event (RsttoThumbnail *thumb,
-                                               GdkEventScroll *event,
-                                               gpointer *user_data)
+cb_rstto_thumbnail_bar_scroll_event (RsttoThumbnailBar *bar,
+                                     GdkEventScroll *event,
+                                     gpointer *user_data)
 {
-    RsttoThumbnailBar *bar = RSTTO_THUMBNAIL_BAR(gtk_widget_get_parent(GTK_WIDGET(thumb)));
     switch(event->direction)
     {
         case GDK_SCROLL_UP:
@@ -718,8 +795,7 @@ cb_rstto_thumbnail_bar_nav_entry_removed(RsttoNavigator *nav, RsttoNavigatorEntr
     {
         if (entry == rstto_thumbnail_get_entry(RSTTO_THUMBNAIL(iter->data)))
         {
-            gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(iter->data), FALSE);
-            g_signal_handlers_disconnect_by_func(G_OBJECT(iter->data), G_CALLBACK(cb_rstto_thumbnail_bar_thumbnail_toggled), bar);
+            g_signal_handlers_disconnect_by_func(G_OBJECT(iter->data), G_CALLBACK(cb_rstto_thumbnail_bar_thumbnail_clicked), bar);
             gtk_widget_destroy(GTK_WIDGET(iter->data));
             break;
         }
